<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" :inline="true">
        <el-form-item label="城市名称">
          <el-input
            v-model="querys[0].value"
            clearable
            placeholder="请输入城市名称"
          />
        </el-form-item>
        <el-form-item>
          <el-button
            type="primary"
            icon="el-icon-search"
            @click="handleSearch"
          >搜索</el-button>
          <el-button
            icon="el-icon-refresh"
            @click="handleReset"
          >重置</el-button>
        </el-form-item>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button
          icon="el-icon-plus"
          type="primary"
          @click="handleAdd"
        >新增</el-button>
        <el-popconfirm
          title="确定删除选中数据吗？"
          @confirm="handleDelete"
        >
          <el-button
            slot="reference"
            :disabled="!multipleSelection.length"
            icon="el-icon-delete"
            type="danger"
            style="margin-left: 10px"
          >删除</el-button>
        </el-popconfirm>
      </div>
      <el-table
        ref="multipleSelection"
        v-loading="loading"
        border
        size="mini"
        :data="tableData"
        :style="{width: '100%'}"
        :max-height="tableMaxHeight"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange"
      >
        <el-table-column type="selection" width="55" />
        <el-table-column
          fixed
          type="index"
          width="55"
          label="序号"
        />
        <el-table-column
          fixed
          sortable
          prop="id"
          label="主建ID"
          show-overflow-tooltip
        />
        <el-table-column
          fixed
          sortable
          prop="city"
          label="城市名称"
          show-overflow-tooltip
        />
        <el-table-column
          fixed
          sortable
          prop="level"
          label="风险城市标记：0-否；1-是"
          show-overflow-tooltip
        />
        <el-table-column
          fixed
          sortable
          prop="updateTime"
          label="更新时间"
          show-overflow-tooltip
        />
      </el-table>
      <el-pagination
        ref="paginationPanel"
        align="right"
        background
        class="bbsl-pagination"
        :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="total"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
      />
    </div>
    <DwdLkEpidemicCityFormDialog ref="formModal" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import DwdLkEpidemicCityApi from '@/views/Manage/dwd/api/DwdLkEpidemicCityApi'
import DwdLkEpidemicCityFormDialog from '@/views/Manage/dwd/components/DwdLkEpidemicCityFormDialog'

export default {
  name: 'DwdLkEpidemicCityManage',
  components: {
    DwdLkEpidemicCityFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/dwdLkEpidemicCity/'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'city',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
	  fuelTypes: []
    }
  },
  created() {

  },
  mounted() {

  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      DwdLkEpidemicCityApi.loadDwdLkEpidemicCity(this.queryParam, res => {
        console.log('=================', res)
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag{
    margin: 0 2px;
}
</style>
